@@ -228,7 +228,7 @@ def get_dataset_name(db, file_name):
     return res
 
 
-def upload_csv(file_name, project_id, tag):
+def upload_csv(path, project_id, tag):
     # headers = {
     #     'Content-Type': 'multipart/form-data; boundary=----WebKitFormBoundary0W2raMzzSKutrSDG',
     #     'Accept': '*/*',
@@ -236,9 +236,9 @@ def upload_csv(file_name, project_id, tag):
     # data = {
     #     f"""$------WebKitFormBoundary0W2raMzzSKutrSDG\\r\\nContent-Disposition: form-data; name': '"file"; filename={file_name}\\r\\nContent-Type: text/csv\\r\\n\\r\\n\\r\\n------WebKitFormBoundary0W2raMzzSKutrSDG--\\r\\n"""
     # }
-    file_name = os.path.basename(file_name)
+    file_name = os.path.basename(path)
     multipart_form_data = {
-        'file': (file_name, open(file_name, 'rb')),
+        'file': (file_name, open(path, 'rb')),
         'action': (None, 'store'),
         'path': (None, '/path1')
     }
@@ -267,6 +267,6 @@ def upload_csv(file_name, project_id, tag):
         }
     }
     if tag:
-        post_data['data']['attributes']['tag_name'] = args.tag
+        post_data['data']['attributes']['tag_name'] = tag
     r = make_request('/source_files', headers=headers, json=post_data)
 
