@@ -25,6 +25,7 @@ def write_default_config():
     config['credentials']['bucket_name'] = ''
     config['credentials']['access_key'] = ''
     config['credentials']['secret_key'] = ''
+    config['credentials']['token'] = ''
 
     with open(get_config_file_path(), 'w') as f:
         config.write(f)
@@ -42,4 +43,5 @@ def get_credentials():
         'bucket_name': config.get('credentials', 'bucket_name', fallback=''),
         'access_key': config.get('credentials', 'access_key', fallback=''),
         'secret_key': config.get('credentials', 'secret_key', fallback=''),
+        'token': config.get('credentials', 'token', fallback=''),
     }
